summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/NetAccess.java
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
commit9ba04742771370f59740e32e11c5f3a1e6a1b70a (patch)
treec81c34dae2b3b1ea73801bf18a960265dc4207f7 /kdejava/koala/org/kde/koala/NetAccess.java
parent1a96c45b22d01378202d9dc7ed9c47acd30f966e (diff)
downloadtdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.tar.gz
tdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.zip
Initial TQt conversion
Diffstat (limited to 'kdejava/koala/org/kde/koala/NetAccess.java')
-rw-r--r--kdejava/koala/org/kde/koala/NetAccess.java54
1 files changed, 27 insertions, 27 deletions
diff --git a/kdejava/koala/org/kde/koala/NetAccess.java b/kdejava/koala/org/kde/koala/NetAccess.java
index d8146aa5..361cb9e5 100644
--- a/kdejava/koala/org/kde/koala/NetAccess.java
+++ b/kdejava/koala/org/kde/koala/NetAccess.java
@@ -2,11 +2,11 @@
package org.kde.koala;
import org.kde.qt.Qt;
-import org.kde.qt.QMetaObject;
+import org.kde.qt.TQMetaObject;
import org.kde.qt.QtSupport;
import java.util.ArrayList;
-import org.kde.qt.QWidget;
-import org.kde.qt.QObject;
+import org.kde.qt.TQWidget;
+import org.kde.qt.TQObject;
/**
@@ -26,9 +26,9 @@ import org.kde.qt.QObject;
@short Provides an easy, synchronous interface to KIO file operations.
*/
-public class NetAccess extends QObject {
+public class NetAccess extends TQObject {
protected NetAccess(Class dummy){super((Class) null);}
- public native QMetaObject metaObject();
+ public native TQMetaObject metaObject();
public native String className();
/**
Downloads a file from an arbitrary URL (<code>src</code>) to a
@@ -76,7 +76,7 @@ public class NetAccess extends QObject {
@short Downloads a file from an arbitrary URL (<code>src</code>) to a temporary file on the local filesystem (<code>target</code>).
@see #lastErrorString
*/
- public static native boolean download(KURL src, StringBuffer target, QWidget window);
+ public static native boolean download(KURL src, StringBuffer target, TQWidget window);
/**
Removes the specified file if and only if it was created
by KIO.NetAccess as a temporary file for a former download.
@@ -105,7 +105,7 @@ public class NetAccess extends QObject {
@short Uploads file <code>src</code> to URL <code>target.</code>
*/
- public static native boolean upload(String src, KURL target, QWidget window);
+ public static native boolean upload(String src, KURL target, TQWidget window);
/**
Alternative to upload for copying over the network.
Overwrite is false, so this will fail if <code>target</code> exists.
@@ -123,12 +123,12 @@ public class NetAccess extends QObject {
@short Alternative to upload for copying over the network.
*/
- public static native boolean copy(KURL src, KURL target, QWidget window);
+ public static native boolean copy(KURL src, KURL target, TQWidget window);
/**
Full-fledged equivalent of KIO.file_copy
@short Full-fledged equivalent of KIO.file_copy
*/
- public static native boolean file_copy(KURL src, KURL dest, int permissions, boolean overwrite, boolean resume, QWidget window);
+ public static native boolean file_copy(KURL src, KURL dest, int permissions, boolean overwrite, boolean resume, TQWidget window);
public static native boolean file_copy(KURL src, KURL dest, int permissions, boolean overwrite, boolean resume);
public static native boolean file_copy(KURL src, KURL dest, int permissions, boolean overwrite);
public static native boolean file_copy(KURL src, KURL dest, int permissions);
@@ -138,7 +138,7 @@ public class NetAccess extends QObject {
Moves or renames one file.
@short Full-fledged equivalent of KIO.file_move.
*/
- public static native boolean file_move(KURL src, KURL target, int permissions, boolean overwrite, boolean resume, QWidget window);
+ public static native boolean file_move(KURL src, KURL target, int permissions, boolean overwrite, boolean resume, TQWidget window);
public static native boolean file_move(KURL src, KURL target, int permissions, boolean overwrite, boolean resume);
public static native boolean file_move(KURL src, KURL target, int permissions, boolean overwrite);
public static native boolean file_move(KURL src, KURL target, int permissions);
@@ -162,26 +162,26 @@ public class NetAccess extends QObject {
@short Alternative method for copying over the network.
*/
- public static native boolean dircopy(KURL src, KURL target, QWidget window);
+ public static native boolean dircopy(KURL src, KURL target, TQWidget window);
/**
Overloaded method, which takes a list of source URLs
@short Overloaded method, which takes a list of source URLs
*/
- public static native boolean dircopy(ArrayList src, KURL target, QWidget window);
+ public static native boolean dircopy(ArrayList src, KURL target, TQWidget window);
public static native boolean dircopy(ArrayList src, KURL target);
/**
Full-fledged equivalent of KIO.move.
Moves or renames one file or directory.
@short Full-fledged equivalent of KIO.move.
*/
- public static native boolean move(KURL src, KURL target, QWidget window);
+ public static native boolean move(KURL src, KURL target, TQWidget window);
public static native boolean move(KURL src, KURL target);
/**
Full-fledged equivalent of KIO.move.
Moves or renames a list of files or directories.
@short Full-fledged equivalent of KIO.move.
*/
- public static native boolean move(ArrayList src, KURL target, QWidget window);
+ public static native boolean move(ArrayList src, KURL target, TQWidget window);
public static native boolean move(ArrayList src, KURL target);
/**
Tests whether a URL exists.
@@ -199,7 +199,7 @@ public class NetAccess extends QObject {
@short Tests whether a URL exists.
*/
- public static native boolean exists(KURL url, boolean source, QWidget window);
+ public static native boolean exists(KURL url, boolean source, TQWidget window);
/**
Tests whether a URL exists and return information on it.
This is a convenience function for KIO.stat
@@ -216,7 +216,7 @@ public class NetAccess extends QObject {
@short Tests whether a URL exists and return information on it.
*/
// bool stat(const KURL& arg1,KIO::UDSEntry& arg2,QWidget* arg3); >>>> NOT CONVERTED
/**
Tries to map a local URL for the given URL.
This is a convenience function for KIO.stat + parsing the
@@ -232,7 +232,7 @@ public class NetAccess extends QObject {
@short Tries to map a local URL for the given URL.
*/
- public static native KURL mostLocalURL(KURL url, QWidget window);
+ public static native KURL mostLocalURL(KURL url, TQWidget window);
/**
Deletes a file or a directory in a synchronous way.
This is a convenience function for KIO.del
@@ -247,7 +247,7 @@ public class NetAccess extends QObject {
@short Deletes a file or a directory in a synchronous way.
*/
- public static native boolean del(KURL url, QWidget window);
+ public static native boolean del(KURL url, TQWidget window);
/**
Creates a directory in a synchronous way.
This is a convenience function for <code>KIO</code>.mkdir
@@ -263,8 +263,8 @@ public class NetAccess extends QObject {
@short Creates a directory in a synchronous way.
*/
- public static native boolean mkdir(KURL url, QWidget window, int permissions);
- public static native boolean mkdir(KURL url, QWidget window);
+ public static native boolean mkdir(KURL url, TQWidget window, int permissions);
+ public static native boolean mkdir(KURL url, TQWidget window);
/**
Executes a remote process via the fish ioslave in a synchronous way.
@param url The remote machine where the command should be executed.
@@ -284,14 +284,14 @@ public class NetAccess extends QObject {
@short Executes a remote process via the fish ioslave in a synchronous way.
*/
- public static native String fish_execute(KURL url, String command, QWidget window);
+ public static native String fish_execute(KURL url, String command, TQWidget window);
/**
This function executes a job in a synchronous way.
If a job fetches some data, pass a byte[] pointer as data parameter to this function
and after the function returns it will contain all the data fetched by this job.
<code>
KIO.Job job = KIO.get( url, false, false );
- QMap<String, String> metaData;
+ TQMap<String, String> metaData;
metaData.insert( "PropagateHttpHeader", "true" );
if ( NetAccess.synchronousRun( job, 0, &data, &url, &metaData ) ) {
String responseHeaders = metaData[ "HTTP-Headers" ];
@@ -316,10 +316,10 @@ public class NetAccess extends QObject {
@short This function executes a job in a synchronous way.
*/
- // bool synchronousRun(KIO::Job* arg1,QWidget* arg2,QByteArray* arg3,KURL* arg4,QMap<QString, QString>* arg5); >>>> NOT CONVERTED
- public static native boolean synchronousRun(Job job, QWidget window, byte[] data, KURL finalURL);
- public static native boolean synchronousRun(Job job, QWidget window, byte[] data);
- public static native boolean synchronousRun(Job job, QWidget window);
+ // bool synchronousRun(KIO::Job* arg1,TQWidget* arg2,TQByteArray* arg3,KURL* arg4,TQMap<TQString, TQString>* arg5); >>>> NOT CONVERTED
+ public static native boolean synchronousRun(Job job, TQWidget window, byte[] data, KURL finalURL);
+ public static native boolean synchronousRun(Job job, TQWidget window, byte[] data);
+ public static native boolean synchronousRun(Job job, TQWidget window);
/**
This function is not implemented!?
(only mimetypeInternal)
@@ -340,7 +340,7 @@ public class NetAccess extends QObject {
@short
*/
- public static native String mimetype(KURL url, QWidget window);
+ public static native String mimetype(KURL url, TQWidget window);
/**
Returns the error string for the last job, in case it failed.
Note that this is already translated.
@@ -216,7 +216,7 @@ public class NetAccess extends QObject {
*/
- // bool stat(const KURL& arg1,KIO::UDSEntry& arg2,QWidget* arg3); >>>> NOT CONVERTED
+ // bool stat(const KURL& arg1,KIO::UDSEntry& arg2,TQWidget* arg3); >>>> NOT CONVERTED
/**
Tries to map a local URL for the given URL.